{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl",
            "label": "CGP file checksum generator",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-chksum/status)\nA Docker container for producing file md5sum and sha512sum. See the [dockstore-cgp-chksum](https://github.com/cancerit/dockstore-cgp-chksum) website for more information.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-chksum:0.4.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-A",
                        "position": 5
                    },
                    "doc": "Flag to suppress all curl exit status",
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_all_curl_exits"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "prefix": "-E",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional curl exit codes to suppress",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_curl_exits"
                },
                {
                    "type": "File",
                    "doc": "file to have checksum generated from",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "use as chksum output instead of generating a new one.",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-j",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-H",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_headers"
                }
            ],
            "baseCommand": [
                "/opt/wtsi-cgp/bin/sums2json.sh"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "yaobo.xu@sanger.ac.uk",
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yx2@sanger.ac.uk"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).check_sums.json"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).server_response.txt"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/server_response"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "A CGP workflow to generate checksum of an interleaved fastq",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "The gzipped interleaved fastq file to import.",
                    "id": "#main/fastq_in"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results of checksums",
                    "id": "#main/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "id": "#main/put_headers"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/in_chksum/chksum_json",
                    "id": "#main/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/in_chksum/server_response",
                    "id": "#main/chksum_put_server_response"
                },
                {
                    "type": "File",
                    "outputSource": "#main/if_input_is_bz2_convert_to_gz_else_just_rename/outfile",
                    "id": "#main/interleaved_fastq_out"
                },
                {
                    "type": "File",
                    "outputSource": "#main/manifest_string_to_file/outfile",
                    "id": "#main/results_manifest"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/fastq_in",
                            "valueFrom": "$(self.basename.replace(/\\.f(?:ast)?q(?:\\.gz|\\.bz2)?$/i, \"\")).fq.gz",
                            "id": "#main/if_input_is_bz2_convert_to_gz_else_just_rename/newname"
                        },
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/if_input_is_bz2_convert_to_gz_else_just_rename/srcfile"
                        }
                    ],
                    "out": [
                        "#main/if_input_is_bz2_convert_to_gz_else_just_rename/outfile"
                    ],
                    "run": "#if_input_is_bz2_convert_to_gz_else_just_rename.cwl",
                    "id": "#main/if_input_is_bz2_convert_to_gz_else_just_rename"
                },
                {
                    "in": [
                        {
                            "source": "#main/fastq_in",
                            "valueFrom": "$(self.basename)",
                            "id": "#main/if_input_is_bz2_generate_md5sum_else_return_input_chksum_json/in_1"
                        },
                        {
                            "source": "#main/if_input_is_bz2_convert_to_gz_else_just_rename/outfile",
                            "id": "#main/if_input_is_bz2_generate_md5sum_else_return_input_chksum_json/in_2"
                        },
                        {
                            "source": "#main/in_chksum/chksum_json",
                            "id": "#main/if_input_is_bz2_generate_md5sum_else_return_input_chksum_json/in_json"
                        }
                    ],
                    "out": [
                        "#main/if_input_is_bz2_generate_md5sum_else_return_input_chksum_json/chksum_json"
                    ],
                    "run": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl",
                    "id": "#main/if_input_is_bz2_generate_md5sum_else_return_input_chksum_json"
                },
                {
                    "in": [
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/in_chksum/ignore_all_curl_exits"
                        },
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/in_chksum/in_file"
                        },
                        {
                            "source": "#main/put_address",
                            "id": "#main/in_chksum/put_address"
                        },
                        {
                            "source": "#main/put_headers",
                            "id": "#main/in_chksum/put_headers"
                        }
                    ],
                    "out": [
                        "#main/in_chksum/chksum_json",
                        "#main/in_chksum/server_response"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#main/in_chksum"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/results_manifest_string/out_string"
                            ],
                            "id": "#main/manifest_string_to_file/in_string"
                        }
                    ],
                    "out": [
                        "#main/manifest_string_to_file/outfile"
                    ],
                    "run": "#string_to_file.cwl",
                    "id": "#main/manifest_string_to_file"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/in_chksum/chksum_json"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/input_chksum_results"
                        },
                        {
                            "source": [
                                "#main/fastq_in"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/input_files"
                        },
                        {
                            "source": [
                                "#main/if_input_is_bz2_generate_md5sum_else_return_input_chksum_json/chksum_json"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/output_chksum_results"
                        },
                        {
                            "source": [
                                "#main/if_input_is_bz2_convert_to_gz_else_just_rename/outfile"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/output_files"
                        }
                    ],
                    "out": [
                        "#main/results_manifest_string/out_string"
                    ],
                    "run": "#results_manifest.cwl",
                    "id": "#main/results_manifest_string"
                }
            ],
            "doc": "A workflow to generate checksums of FastQ files and an interleaved FastQ from them. See the [workflow-seq-import](https://github.com/cancerit/workflow-seq-import) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/workflow-seq-import",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yyaobo@gmail.com",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "genservhelp@sanger.ac.uk"
            }
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": true
                    },
                    "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl/file_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "shellQuote": true
                    },
                    "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl/in_json"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_json.basename)"
                    },
                    "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl/out_json"
                }
            ],
            "baseCommand": [
                "bash",
                "-c",
                "set -x; in=$0; json=$1; bz2_pattern=\"*.bz2\"; if [[ $in == $bz2_pattern ]]; then echo 'file_name is bz2, I will have no output'; else echo 'file_name is not bz2, I will output the input json file'; cp $json $(basename $json); fi"
            ],
            "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$(inputs.srcfile)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "shellQuote": true
                    },
                    "id": "#if_input_is_bz2_convert_to_gz_else_just_rename.cwl/newname"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": true
                    },
                    "id": "#if_input_is_bz2_convert_to_gz_else_just_rename.cwl/srcfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.newname)"
                    },
                    "id": "#if_input_is_bz2_convert_to_gz_else_just_rename.cwl/outfile"
                }
            ],
            "baseCommand": [
                "bash",
                "-c",
                "set -x; in=$0; out=$1; bz2_pattern=\"*.bz2\"; if [[ $in == $bz2_pattern ]]; then echo 'converting bz2 file to gzip file..'; bzip2 -cd $in | gzip -c > $out; elif [[ $(basename $in) != $out ]]; then echo 'only need to rename the file'; mv $in $out; fi"
            ],
            "id": "#if_input_is_bz2_convert_to_gz_else_just_rename.cwl"
        },
        {
            "class": "Workflow",
            "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl",
            "label": "If Input file 1 has bz2 extension generate md5sum from input file 2 else returns input chksum json",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/in_1"
                },
                {
                    "type": "File",
                    "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/in_2"
                },
                {
                    "type": "File",
                    "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/in_json"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/chksum/chksum_json",
                    "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/chksum_json"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/in_2",
                            "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/chksum/in_file"
                        },
                        {
                            "source": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/out_json",
                            "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/chksum/in_json"
                        }
                    ],
                    "out": [
                        "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/chksum/chksum_json"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/chksum"
                },
                {
                    "in": [
                        {
                            "source": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/in_1",
                            "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/file_name"
                        },
                        {
                            "source": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/in_json",
                            "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/in_json"
                        }
                    ],
                    "out": [
                        "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/out_json"
                    ],
                    "run": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl",
                    "id": "#if_input_is_bz2_generate_md5sum_else_return_input_chksum_json.cwl/if_input_is_bz2_generate_md5sum_else_returns_input_chksum_json/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest.cwl/input_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest.cwl/input_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest.cwl/output_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest.cwl/output_files"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#results_manifest.cwl/output_rg_info_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#results_manifest.cwl/out_string"
                }
            ],
            "expression": "${\n  function name_and_chksum(files, chksum_out_json_files) {\n    var metas = [];\n    for (var i=0; i<files.length; i++) {\n      var temp_obj = JSON.parse(chksum_out_json_files[i].contents);\n      metas.push({name: files[i].basename, size: files[i].size, md5: temp_obj.md5sum, sha2: temp_obj.sha2sum});\n    }\n    return metas;\n  }\n\n  function name_and_checksum_and_rg(files, chksum_out_json_files, rg_info_file){\n    var metas = [];\n    var rg_obj = JSON.parse(rg_info_file.contents);\n    var rg_dict = {};\n    for(var j=0; j<rg_obj.length; j++){ \n      rg_dict[rg_obj[j][\"ID\"]] = rg_obj[j];   \n    }\n    for (var i=0; i<files.length; i++) {\n      //Use file basename e.g. rg_split_10659_i.fq.gz to get RG ID\n      var rg_id = (files[i].basename).slice(9,-8);\n      var temp_obj = JSON.parse(chksum_out_json_files[i].contents);\n      metas.push({name: files[i].basename, size: files[i].size, md5: temp_obj.md5sum, sha2: temp_obj.sha2sum, rg_info: rg_dict[rg_id]});\n    }\n    return metas;\n  }\n\n  var final_meta;\n  if (inputs.output_rg_info_file) {\n      final_meta = { input: name_and_chksum(inputs.input_files, inputs.input_chksum_results), output: name_and_checksum_and_rg(inputs.output_files, inputs.output_chksum_results, inputs.output_rg_info_file) };\n  } else {\n      final_meta = { input: name_and_chksum(inputs.input_files, inputs.input_chksum_results), output: name_and_chksum(inputs.output_files, inputs.output_chksum_results) };\n  }\n  return {out_string: JSON.stringify(final_meta)} \n}\n",
            "id": "#results_manifest.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#string_to_file.cwl/in_string"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results_manifest.json"
                    },
                    "id": "#string_to_file.cwl/outfile"
                }
            ],
            "baseCommand": [
                "echo"
            ],
            "stdout": "results_manifest.json",
            "id": "#string_to_file.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
